@@ -14,6 +14,14 @@ __all__ = ["aszarr"]
 
 logger = logging.getLogger("utoolbox.cli.aszarr")
 
+ASZARR_SLURM_SPEC = {
+    "cores": 8,
+    "processes": 1,
+    "memory": "32GB",
+    "project": "aszarr",
+    "queue": "CPU",
+}
+
 
 def _remap_and_flip(ds, remap, flip):
     if not isinstance(ds, TiledDataset):
@@ -57,13 +65,12 @@ def _remap_and_flip(ds, remap, flip):
 @click.option(
     "-h",
     "--host",
-    "client",
     type=str,
     default=None,
     metavar="HOST",
     help="Cluster scheduler to perform the conversion.",
 )
-def aszarr(path, verbose, remap, flip, client, output):
+def aszarr(path, verbose, remap, flip, host, output):
     """
     Convert arbitrary dataset into Zarr dataset format.
 
@@ -116,17 +123,66 @@ def aszarr(path, verbose, remap, flip, client, output):
     else:
         dump, overwrite = True, False
 
-    if dump:
-        desc = "start dumping"
-        if client:
-            client = Client(client)
-            desc += f' (using scheduler "{client.scheduler.address}")'
-        logger.info(desc)
+    class SelfSupervisedClient:
+        def __init__(self, address, jobs=1, **kwargs):
+            if jobs < 1:
+                logger.error("number of jobs must be a positive integer")
+                jobs = 1
+            self._jobs = jobs
 
-        try:
-            ZarrDataset.dump(dst_path, ds, overwrite=overwrite, client=client)
-        finally:
-            if client:
-                client.close()
+            if address == "slurm":
+                from dask_jobqueue import SLURMCluster
+
+                cluster = SLURMCluster(**kwargs)
+
+                # scalue up immediately
+                assert jobs >= 1, "number of jobs must be a positive integer"
+                cluster.scale(jobs=self.jobs)
+
+                logger.info(f"launched {self.jobs} job request(s)")
+            else:
+                cluster = address
+            self.cluster = cluster
+
+        def __enter__(self):
+            self.client = Client(self.cluster)
+            self.client.wait_for_workers(self.jobs)
+            return self
+
+        def __exit__(self, *exc):
+            self.client.close()
+            self.client = None
+
+            if self.cluster:
+                self.cluster.close()
+            self.cluster = None
+
+        ##
+
+        @property
+        def jobs(self):
+            return self._jobs
+
+    if dump:
+        with SelfSupervisedClient(host, jobs=20, **ASZARR_SLURM_SPEC) as sc:
+
+            # connect to the cluster
+            client = sc.client
+            scheduler_info = client.scheduler_info()
+
+            # scheduler info
+            address = scheduler_info["address"]
+            logger.info(f"start dumping (scheduler: {address})")
+
+            # dashboard info
+            try:
+                port = scheduler_info["services"]["dashboard"]
+                address, _ = address.rsplit(":", maxsplit=1)
+                address = f"{address}:{port}"
+                logger.info(f"dashboard address: {address}")
+            except KeyError:
+                logger.warning(f"no dashboard")
+
+            ZarrDataset.dump(dst_path, ds, overwrite=overwrite)
 
     logger.info("complete zarr dataset conversion")
